@@ -22,7 +22,7 @@ from ._response import BatchResponse, Response
 from ._serializer import JSONSerializer
 from ._wsgi import WSGIHandler
 
-__all__: Final[tuple[str, ...]] = (
+__all__: Final[list[str]] = [
     "BatchRequest",
     "BatchResponse",
     "Dispatcher",
@@ -32,6 +32,6 @@ __all__: Final[tuple[str, ...]] = (
     "Request",
     "Response",
     "WSGIHandler"
-)
+]
 
-__version__: Final[str] = "1.0.2"
+__version__: Final[str] = "2.0.0"
