@@ -15,47 +15,43 @@
 
 from abc import ABCMeta, abstractmethod
 from collections.abc import Callable, Iterator, MutableMapping
-from contextvars import Context, copy_context
 from functools import partial
 from inspect import Signature, isfunction
 from typing import Any, Final, TypeVar
 
 from ._errors import Error, ErrorEnum
 
-__all__: Final[tuple[str, ...]] = (
-    "BaseDispatcher",
-    "Dispatcher"
-)
+__all__: Final[list[str]] = ["Dispatcher"]
 
 _F = TypeVar("_F", bound=Callable)
 
 
 class BaseDispatcher(MutableMapping[str, _F], metaclass=ABCMeta):
-    __slots__: str = "references"
+    __slots__: list[str] = ["_references"]
 
-    def __init__(self, /, **references: _F) -> None:
-        self.references: dict[str, _F] = references
+    def __init__(self, /, **kwargs: _F) -> None:
+        self._references: Final[dict[str, _F]] = kwargs.copy()
 
     def __hash__(self) -> int:
         return hash(frozenset(self.items()))
 
     def __getitem__(self, key: str, /) -> _F:
-        return self.references[key]
+        return self._references[key]
 
     def __setitem__(self, key: str, value: _F, /) -> None:
-        self.references[key] = value
+        self._references[key] = value
 
     def __delitem__(self, key: str, /) -> None:
-        del self.references[key]
+        del self._references[key]
 
     def __len__(self) -> int:
-        return len(self.references)
+        return len(self._references)
 
     def __iter__(self) -> Iterator[str]:
-        return iter(self.references)
+        return iter(self._references)
 
     def __contains__(self, obj: Any, /) -> bool:
-        return obj in self.references
+        return obj in self._references
 
     @abstractmethod
     def register(self, user_function: _F | None = None, *, function_name: str | None = None) -> _F | Callable[[_F], _F]:
@@ -72,9 +68,6 @@ class Dispatcher(BaseDispatcher[Callable]):
     Besides the methods inherited from the parent class,
     this class provides methods for the registering and dispatching user-defined functions.
 
-    :var references: Instance variable representing the :py:class:`collections.abc.MutableMapping` object
-        for proxying the interface methods.
-
     .. note::
         Unlike the parent class :py:class:`collections.abc.MutableMapping`,
         this object is provided the hash value by invoking :py:func:`hash` method.
@@ -83,9 +76,6 @@ class Dispatcher(BaseDispatcher[Callable]):
     """
     __slots__: tuple[str, ...] = ()
 
-    def __init__(self) -> None:
-        super(Dispatcher, self).__init__()
-
     def __repr__(self) -> str:
         return f"<{__package__}.{self.__class__.__name__}()>"
 
@@ -158,8 +148,8 @@ class Dispatcher(BaseDispatcher[Callable]):
             raise Error(code=ErrorEnum.INVALID_PARAMETERS, message=f"Invalid parameters: {exc!s}") from exc
 
         try:
-            context: Final[Context] = copy_context()
-            return context.run(user_function, *args, **kwargs)
+            callback: Final[partial] = partial(user_function, *args, **kwargs)
+            return callback()
         except Error:
             raise
         except Exception as exc:
