@@ -19,11 +19,7 @@ from typing import Any, Final, SupportsInt
 
 from ._utilities import Undefined, UndefinedType, make_hashable
 
-__all__: Final[tuple[str, ...]] = (
-    "BaseError",
-    "Error",
-    "ErrorEnum"
-)
+__all__: Final[list[str]] = ["Error", "ErrorEnum"]
 
 
 class ErrorEnum(IntEnum):
@@ -71,13 +67,13 @@ class Error(BaseError):
     An object representing a common exception for all encountered errors in the JSON-RPC protocol.
     This object can be used in user-defined functions to throw user-defined exception with the custom error code for example.
     """
-    __slots__: tuple[str, ...] = "_code", "_message", "_data"
+    __slots__: list[str] = ["_code", "_message", "_data"]
 
     def __init__(self, *, code: SupportsInt, message: str, data: Any = Undefined) -> None:
         super(Error, self).__init__(message)
-        self._code: int = int(code)
-        self._message: str = str(message)
-        self._data: Any = data
+        self._code: Final[int] = int(code)
+        self._message: Final[str] = str(message)
+        self._data: Final[Any] = data
 
     def __str__(self) -> str:
         return f"{self._message!s}\x20\x28{self._code:d}\x29"
@@ -93,9 +89,9 @@ class Error(BaseError):
 
     def __eq__(self, obj: Any, /) -> bool:
         return isinstance(obj, self.__class__) \
-            and self._code == obj._code \
-            and self._message == obj._message \
-            and self._data == obj._data
+            and type(self._code) == type(obj._code) and self._code == obj._code \
+            and type(self._message) == type(obj._message) and self._message == obj._message \
+            and type(self._data) == type(obj._data) and self._data == obj._data
 
     @property
     def code(self) -> int:
