@@ -18,15 +18,10 @@ from collections.abc import Iterable, Iterator, MutableMapping, MutableSequence
 from numbers import Number
 from typing import Any, Final, TypeAlias, TypeVar
 
-from ._errors import BaseError, Error, ErrorEnum
+from ._errors import Error, ErrorEnum
 from ._utilities import Undefined, UndefinedType, make_hashable
 
-__all__: Final[tuple[str, ...]] = (
-    "BaseBatchRequest",
-    "BaseRequest",
-    "BatchRequest",
-    "Request"
-)
+__all__: Final[list[str]] = ["BatchRequest", "Request"]
 
 _T = TypeVar("_T")
 _Args: TypeAlias = MutableSequence[Any]
@@ -63,11 +58,11 @@ class BaseRequest(metaclass=ABCMeta):
 
     @classmethod
     @abstractmethod
-    def from_json(cls, obj: dict[str, Any], /) -> "BaseRequest | BaseError":
+    def from_json(cls: type[_T], obj: dict[str, Any], /) -> _T | Error:
         raise NotImplementedError
 
 
-class BaseBatchRequest(Iterable[BaseRequest | BaseError]):
+class BaseBatchRequest(Iterable[BaseRequest | Error]):
     __slots__: tuple[str, ...] = ()
 
     @abstractmethod
@@ -76,7 +71,7 @@ class BaseBatchRequest(Iterable[BaseRequest | BaseError]):
 
     @classmethod
     @abstractmethod
-    def from_json(cls, obj: list[dict[str, Any]], /) -> "BaseBatchRequest":
+    def from_json(cls: type[_T], obj: list[dict[str, Any]], /) -> _T:
         raise NotImplementedError
 
 
@@ -94,16 +89,16 @@ class Request(BaseRequest):
         aren't an objects of type :py:class:`collections.abc.MutableSequence` or :py:class:`collections.abc.MutableMapping` if provided,
         also if the request identifier isn't an object of type :py:class:`str` or :py:class:`numbers.Number` if provided.
     """
-    __slots__: tuple[str, ...] = "_method", "_params", "_id"
+    __slots__: list[str] = ["_method", "_params", "_id"]
 
     def __init__(self, *,
         method: str,
         params: _Args | _Kwargs | UndefinedType = Undefined,
         request_id: str | Number | UndefinedType = Undefined
     ) -> None:
-        self._method: str = self._is_method_valid(method=method)
-        self._params: _Args | _Kwargs | UndefinedType = self._is_params_valid(params=params)
-        self._id: str | Number | UndefinedType = self._is_request_id_valid(request_id=request_id)
+        self._method: Final[str] = self._is_method_valid(method=method)
+        self._params: Final[_Args | _Kwargs | UndefinedType] = self._is_params_valid(params=params)
+        self._id: Final[str | Number | UndefinedType] = self._is_request_id_valid(request_id=request_id)
 
     def __repr__(self) -> str:
         return f"<{__package__}.{self.__class__.__name__}(" \
@@ -116,9 +111,9 @@ class Request(BaseRequest):
 
     def __eq__(self, obj: Any, /) -> bool:
         return isinstance(obj, self.__class__) \
-            and self._method == obj._method \
-            and self._params == obj._params \
-            and self._id == obj._id
+            and type(self._method) == type(obj._method) and self._method == obj._method \
+            and type(self._params) == type(obj._params) and self._params == obj._params \
+            and type(self._id) == type(obj._id) and self._id == obj._id
 
     def _is_method_valid(self, *, method: _T) -> _T:
         if not isinstance(method, str) or method.startswith("\x72\x70\x63\x2E"):
@@ -181,7 +176,7 @@ class Request(BaseRequest):
         return isinstance(self._id, UndefinedType)
 
     @classmethod
-    def from_json(cls, obj: dict[str, Any], /) -> "Request | Error":
+    def from_json(cls: type[_T], obj: dict[str, Any], /) -> _T | Error:
         """
         The class method for creating the :class:`jsonrpc.Request` object from :py:class:`dict` object.
         Primarily used by the :class:`jsonrpc.WSGIHandler` instance.
@@ -207,7 +202,7 @@ class Request(BaseRequest):
                     return Request(method=method)
                 case _:
                     raise Error(code=ErrorEnum.INVALID_REQUEST, message="Invalid request object", data=obj)
-        except BaseError as error:
+        except Error as error:
             return error
 
 
@@ -215,34 +210,31 @@ class BatchRequest(BaseBatchRequest[Request | Error]):
     """
     The :py:class:`collections.abc.Iterable` subclass representing the collection
     of :class:`jsonrpc.Request` and :class:`jsonrpc.Error` objects.
-
-    :var requests: Instance variable representing the :py:class:`tuple` object
-        for proxying the :py:class:`collections.abc.Iterable` interface methods.
     """
-    __slots__: str = "requests"
+    __slots__: list[str] = ["_requests"]
 
     def __init__(self, requests: Iterable[Request | Error], /) -> None:
-        self.requests: tuple[Request | Error, ...] = tuple(requests)
+        self._requests: Final[tuple[Request | Error, ...]] = tuple(requests)
 
     def __repr__(self) -> str:
-        return f"<{__package__}.{self.__class__.__name__}({self.requests!r})>"
+        return f"<{__package__}.{self.__class__.__name__}({self._requests!r})>"
 
     def __hash__(self) -> int:
-        return hash(self.requests)
+        return hash(frozenset(self._requests)) ^ len(self._requests)
 
     def __eq__(self, obj: Any, /) -> bool:
         return isinstance(obj, self.__class__) \
-            and len(self.requests) == len(obj.requests) \
-            and frozenset(self.requests).issubset(obj.requests)
+            and len(self._requests) == len(obj._requests) \
+            and frozenset(self._requests) == frozenset(obj._requests)
 
     def __iter__(self) -> Iterator[Request | Error]:
-        return iter(self.requests)
+        return iter(self._requests)
 
     def __len__(self) -> int:
-        return len(self.requests)
+        return len(self._requests)
 
     @classmethod
-    def from_json(cls, obj: list[dict[str, Any]], /) -> "BatchRequest":
+    def from_json(cls: type[_T], obj: list[dict[str, Any]], /) -> _T:
         """
         The class method for creating the :class:`jsonrpc.BatchRequest` object from :py:class:`collections.abc.Iterable`
         of :py:class:`dict` objects.
