@@ -19,15 +19,10 @@ from numbers import Number
 from types import NoneType
 from typing import Any, Final, TypeVar, overload
 
-from ._errors import BaseError, Error
+from ._errors import Error
 from ._utilities import Undefined, UndefinedType, make_hashable
 
-__all__: Final[tuple[str, ...]] = (
-    "BaseBatchResponse",
-    "BaseResponse",
-    "BatchResponse",
-    "Response"
-)
+__all__: Final[list[str]] = ["BatchResponse", "Response"]
 
 _T = TypeVar("_T")
 
@@ -42,7 +37,7 @@ class BaseResponse(metaclass=ABCMeta):
 
     @property
     @abstractmethod
-    def error(self) -> BaseError:
+    def error(self) -> Error:
         raise NotImplementedError
 
     @property
@@ -87,7 +82,7 @@ class Response(BaseResponse):
     :raises TypeError: If both or no one ``body`` or ``error`` attributes are set
         or response identifier isn't the same type as request identifier.
     """
-    __slots__: tuple[str, ...] = "_body", "_error", "_id"
+    __slots__: list[str] = ["_body", "_error", "_id"]
 
     @overload
     def __init__(self, *,
@@ -107,9 +102,9 @@ class Response(BaseResponse):
         response_id: str | Number | UndefinedType | None = Undefined
     ) -> None:
         self._is_body_and_error_valid(body=body, error=error)
-        self._body: Any = body
-        self._error: Error | UndefinedType = error
-        self._id: str | Number | UndefinedType | None = self._is_response_id_valid(response_id=response_id)
+        self._body: Final[Any] = body
+        self._error: Final[Error | UndefinedType] = error
+        self._id: Final[str | Number | UndefinedType | None] = self._is_response_id_valid(response_id=response_id)
 
     def __repr__(self) -> str:
         return f"<{__package__}.{self.__class__.__name__}(" \
@@ -122,9 +117,9 @@ class Response(BaseResponse):
 
     def __eq__(self, obj: Any, /) -> bool:
         return isinstance(obj, self.__class__) \
-            and self._body == obj._body \
-            and self._error == obj._error \
-            and self._id == obj._id
+            and type(self._body) == type(obj._body) and self._body == obj._body \
+            and type(self._error) == type(obj._error) and self._error == obj._error \
+            and type(self._id) == type(obj._id) and self._id == obj._id
 
     def _is_body_and_error_valid(self, *, body: Any, error: Error | UndefinedType) -> None:
         if isinstance(body, UndefinedType) == isinstance(error, UndefinedType):
@@ -213,29 +208,28 @@ class BatchResponse(BaseBatchResponse[Response]):
     """
     The :py:class:`collections.abc.Iterable` subclass representing the unordered collection
     of :class:`jsonrpc.Response` unique objects.
-
-    :var requests: Instance variable representing the :py:class:`frozenset` object
-        for proxying the :py:class:`collections.abc.Iterable` interface methods.
     """
-    __slots__: str = "responses"
+    __slots__: list[str] = ["_responses"]
 
     def __init__(self, responses: Iterable[Response], /) -> None:
-        self.responses: frozenset[Response] = frozenset(responses)
+        self._responses: Final[frozenset[Response]] = frozenset(responses)
 
     def __repr__(self) -> str:
         return f"<{__package__}.{self.__class__.__name__}(\u2026)>"
 
     def __hash__(self) -> int:
-        return hash(self.responses)
+        return hash(self._responses) ^ len(self._responses)
 
     def __eq__(self, obj: Any, /) -> bool:
-        return isinstance(obj, self.__class__) and self.responses == obj.responses
+        return isinstance(obj, self.__class__) \
+            and len(self._responses) == len(obj._responses) \
+            and self._responses == obj._responses
 
     def __iter__(self) -> Iterator[Response]:
-        return iter(self.responses)
+        return iter(self._responses)
 
     def __len__(self) -> int:
-        return len(self.responses)
+        return len(self._responses)
 
     @property
     def json(self) -> list[dict[str, Any]]:
@@ -258,5 +252,5 @@ class BatchResponse(BaseBatchResponse[Response]):
                 {"jsonrpc": "2.0", "error": {"code": -32603, "message": "Unexpected error"}, "id": "6ba7b810-9dad-11d1-80b4-00c04fd430c8"}
             ]
         """
-        sorter: Final[Callable[[dict[str, Any]], bool]] = lambda obj: "result" in obj and "error" not in obj
+        sorter: Callable[[dict[str, Any]], bool] = lambda obj: "result" in obj and "error" not in obj
         return sorted(map(lambda response: response.json, self), key=sorter, reverse=True)
