@@ -20,10 +20,7 @@ from typing import Any, Final
 
 from ._errors import Error, ErrorEnum
 
-__all__: Final[tuple[str, ...]] = (
-    "BaseSerializer",
-    "JSONSerializer"
-)
+__all__: Final[list[str]] = ["JSONSerializer"]
 
 # Ensure to output JSON as a strict JavaScript subset:
 _JSON_ESCAPE_TABLE: Final[dict[int, str]] = {
@@ -50,11 +47,11 @@ class JSONSerializer(BaseSerializer):
     Combines the :py:class:`json.JSONEncoder` and :py:class:`json.JSONDecoder` objects.
     Primarily used by the :class:`jsonrpc.WSGIHandler` instance for (de)serialization the requests and responses.
     """
-    __slots__: tuple[str, ...] = "_encoder", "_decoder"
+    __slots__: list[str] = ["_encoder", "_decoder"]
 
     def __init__(self) -> None:
-        self._encoder: JSONEncoder = JSONEncoder(ensure_ascii=False, separators=("\u002c", "\u003a"))
-        self._decoder: JSONDecoder = JSONDecoder(strict=False)
+        self._encoder: Final[JSONEncoder] = JSONEncoder(ensure_ascii=False, separators=("\x2C", "\x3A"))
+        self._decoder: Final[JSONDecoder] = JSONDecoder(strict=False)
 
     def __repr__(self) -> str:
         return f"<{__package__}.{self.__class__.__name__}()>"
